@@ -1,12 +1,12 @@
 from mcpi_e.minecraft import Minecraft
-from mcpi_e import block
+from mcpi_e.BlockEnum import BlockEnum
 from time import sleep
 from random import *
 
 
 address="192.168.1.155"#if not pass address, it will be localhost
-port=4712 #default port for RaspberryJuice plugin
-name="stoneskinkknn"
+port=4711 #default port for RaspberryJuice plugin 4711
+name="stoneskin"
 #mc = Minecraft.create()
 mc=Minecraft.create(address,port,name)
 
@@ -15,5 +15,8 @@ while(True):
     x,y,z=mc.player.getTilePos()
     id=mc.getBlock(x,y-1,z)
     if(id!=currentId):
-        print(str(id))
+        if(BlockEnum.has_value(id)):
+            print(BlockEnum(id))
+        else:
+            print(str(id))
     currentId=id
\ No newline at end of file
