@@ -14,7 +14,7 @@ mc=Minecraft.create(address,port,name)
 #wmc.setBlock(x+1,y,z,217)
 
 id=mc.getBlock(x+1,y,z)
-#print("blockid get"+str(id))
+print("blockid get"+str(id))
 
 #     print("set "+str(i))
 i=0
